balance

package
v1.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2026 License: MIT Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	GetBalanceResponse_Result_name = map[int32]string{
		0: "OK",
		1: "DENIED",
		2: "NOT_FOUND",
	}
	GetBalanceResponse_Result_value = map[string]int32{
		"OK":        0,
		"DENIED":    1,
		"NOT_FOUND": 2,
	}
)

Enum value maps for GetBalanceResponse_Result.

var Balance_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "ocp.balance.v1.Balance",
	HandlerType: (*BalanceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetBalance",
			Handler:    _Balance_GetBalance_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "balance/v1/ocp_balance_service.proto",
}

Balance_ServiceDesc is the grpc.ServiceDesc for Balance service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_balance_v1_ocp_balance_service_proto protoreflect.FileDescriptor

Functions

func RegisterBalanceServer

func RegisterBalanceServer(s grpc.ServiceRegistrar, srv BalanceServer)

Types

type BalanceClient

type BalanceClient interface {
	// GetBalance returns balance data for any owner account
	GetBalance(ctx context.Context, in *GetBalanceRequest, opts ...grpc.CallOption) (*GetBalanceResponse, error)
}

BalanceClient is the client API for Balance service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewBalanceClient

func NewBalanceClient(cc grpc.ClientConnInterface) BalanceClient

type BalanceServer

type BalanceServer interface {
	// GetBalance returns balance data for any owner account
	GetBalance(context.Context, *GetBalanceRequest) (*GetBalanceResponse, error)
	// contains filtered or unexported methods
}

BalanceServer is the server API for Balance service. All implementations must embed UnimplementedBalanceServer for forward compatibility

type GetBalanceRequest

type GetBalanceRequest struct {
	Owner *v1.SolanaAccountId `protobuf:"bytes,1,opt,name=owner,proto3" json:"owner,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBalanceRequest) Descriptor deprecated

func (*GetBalanceRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetBalanceRequest.ProtoReflect.Descriptor instead.

func (*GetBalanceRequest) GetOwner

func (x *GetBalanceRequest) GetOwner() *v1.SolanaAccountId

func (*GetBalanceRequest) ProtoMessage

func (*GetBalanceRequest) ProtoMessage()

func (*GetBalanceRequest) ProtoReflect

func (x *GetBalanceRequest) ProtoReflect() protoreflect.Message

func (*GetBalanceRequest) Reset

func (x *GetBalanceRequest) Reset()

func (*GetBalanceRequest) String

func (x *GetBalanceRequest) String() string

func (*GetBalanceRequest) Validate

func (m *GetBalanceRequest) Validate() error

Validate checks the field values on GetBalanceRequest with the rules defined in the proto definition for this message. If any rules are violated, an error is returned.

type GetBalanceRequestValidationError

type GetBalanceRequestValidationError struct {
	// contains filtered or unexported fields
}

GetBalanceRequestValidationError is the validation error returned by GetBalanceRequest.Validate if the designated constraints aren't met.

func (GetBalanceRequestValidationError) Cause

Cause function returns cause value.

func (GetBalanceRequestValidationError) Error

Error satisfies the builtin error interface

func (GetBalanceRequestValidationError) ErrorName

ErrorName returns error name.

func (GetBalanceRequestValidationError) Field

Field function returns field value.

func (GetBalanceRequestValidationError) Key

Key function returns key value.

func (GetBalanceRequestValidationError) Reason

Reason function returns reason value.

type GetBalanceResponse

type GetBalanceResponse struct {
	Result        GetBalanceResponse_Result `protobuf:"varint,1,opt,name=result,proto3,enum=ocp.balance.v1.GetBalanceResponse_Result" json:"result,omitempty"`
	CoreMintValue uint64                    `protobuf:"varint,2,opt,name=core_mint_value,json=coreMintValue,proto3" json:"core_mint_value,omitempty"`
	// contains filtered or unexported fields
}

func (*GetBalanceResponse) Descriptor deprecated

func (*GetBalanceResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetBalanceResponse.ProtoReflect.Descriptor instead.

func (*GetBalanceResponse) GetCoreMintValue

func (x *GetBalanceResponse) GetCoreMintValue() uint64

func (*GetBalanceResponse) GetResult

func (*GetBalanceResponse) ProtoMessage

func (*GetBalanceResponse) ProtoMessage()

func (*GetBalanceResponse) ProtoReflect

func (x *GetBalanceResponse) ProtoReflect() protoreflect.Message

func (*GetBalanceResponse) Reset

func (x *GetBalanceResponse) Reset()

func (*GetBalanceResponse) String

func (x *GetBalanceResponse) String() string

func (*GetBalanceResponse) Validate

func (m *GetBalanceResponse) Validate() error

Validate checks the field values on GetBalanceResponse with the rules defined in the proto definition for this message. If any rules are violated, an error is returned.

type GetBalanceResponseValidationError

type GetBalanceResponseValidationError struct {
	// contains filtered or unexported fields
}

GetBalanceResponseValidationError is the validation error returned by GetBalanceResponse.Validate if the designated constraints aren't met.

func (GetBalanceResponseValidationError) Cause

Cause function returns cause value.

func (GetBalanceResponseValidationError) Error

Error satisfies the builtin error interface

func (GetBalanceResponseValidationError) ErrorName

ErrorName returns error name.

func (GetBalanceResponseValidationError) Field

Field function returns field value.

func (GetBalanceResponseValidationError) Key

Key function returns key value.

func (GetBalanceResponseValidationError) Reason

Reason function returns reason value.

type GetBalanceResponse_Result

type GetBalanceResponse_Result int32
const (
	GetBalanceResponse_OK        GetBalanceResponse_Result = 0
	GetBalanceResponse_DENIED    GetBalanceResponse_Result = 1
	GetBalanceResponse_NOT_FOUND GetBalanceResponse_Result = 2
)

func (GetBalanceResponse_Result) Descriptor

func (GetBalanceResponse_Result) Enum

func (GetBalanceResponse_Result) EnumDescriptor deprecated

func (GetBalanceResponse_Result) EnumDescriptor() ([]byte, []int)

Deprecated: Use GetBalanceResponse_Result.Descriptor instead.

func (GetBalanceResponse_Result) Number

func (GetBalanceResponse_Result) String

func (x GetBalanceResponse_Result) String() string

func (GetBalanceResponse_Result) Type

type UnimplementedBalanceServer

type UnimplementedBalanceServer struct {
}

UnimplementedBalanceServer must be embedded to have forward compatible implementations.

func (UnimplementedBalanceServer) GetBalance

type UnsafeBalanceServer

type UnsafeBalanceServer interface {
	// contains filtered or unexported methods
}

UnsafeBalanceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BalanceServer will result in compilation errors.

Jump to